==> react-layout-grid-2.4.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import LayoutGridItem from './gridItem';
import cx from 'classnames';
import { ALIGN_ITEMS, ALIGN_CONTENT, BASE_CLASS, JUSTIFY_CONTENT, GUTTER_VALUES, CELL_NUMBERS, BREAKPOINTS } from './settings';
import { jsx as _jsx } from "react/jsx-runtime";

var transition = function transition(_ref) {
  var isGapless = _ref.isGapless,
      oldProps = _objectWithoutPropertiesLoose(_ref, ["isGapless"]);

  var gutter = oldProps.gutter || isGapless ? 0 : undefined;
  return _extends({
    gutter: gutter
  }, oldProps);
};

var getGutterClassNames = function getGutterClassNames(gutterConfig) {
  if (gutterConfig === void 0) {
    gutterConfig = {};
  }

  if (GUTTER_VALUES.includes(gutterConfig)) {
    return BASE_CLASS + "--gutter-" + BREAKPOINTS.XXS + "-" + gutterConfig;
  } else if (typeof gutterConfig === 'object') {
    return Object.entries(gutterConfig).map(function (_ref2) {
      var key = _ref2[0],
          value = _ref2[1];
      return Object.values(BREAKPOINTS).includes(key) ? BASE_CLASS + "--gutter-" + key + "-" + value : null;
    }).filter(function (value) {
      return value !== null;
    }).join(' ');
  }

  return null;
};

function LayoutGrid(_ref3) {
  var alignContent = _ref3.alignContent,
      alignItems = _ref3.alignItems,
      children = _ref3.children,
      justifyContent = _ref3.justifyContent,
      gutter = _ref3.gutter;
  var classNames = cx("" + BASE_CLASS, Object.values(ALIGN_CONTENT).includes(alignContent) && BASE_CLASS + "--ac-" + alignContent, Object.values(ALIGN_ITEMS).includes(alignItems) && BASE_CLASS + "--ai-" + alignItems, Object.values(JUSTIFY_CONTENT).includes(justifyContent) && BASE_CLASS + "--jc-" + justifyContent, getGutterClassNames(gutter));
  return /*#__PURE__*/_jsx("div", {
    className: classNames,
    children: children
  });
}

LayoutGrid.displayName = 'LayoutGrid';

var DeprecatedLayoutGrid = function DeprecatedLayoutGrid(props) {
  return /*#__PURE__*/_jsx(LayoutGrid, _extends({}, transition(props)));
};

export default LayoutGrid;
export { DeprecatedLayoutGrid, LayoutGridItem, ALIGN_CONTENT as LayoutGridAlignContent, ALIGN_ITEMS as LayoutGridAlignItems, JUSTIFY_CONTENT as LayoutGridJustifyContent, GUTTER_VALUES as LayoutGridGutterValues, CELL_NUMBERS as LayoutGridCellNumbers, BREAKPOINTS as LayoutGridBreakpoints };

==> react-layout-grid-2.8.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["isGapless"];
import PropTypes from 'prop-types';
import LayoutGridItem from './gridItem';
import cx from 'classnames';
import { ALIGN_ITEMS, ALIGN_CONTENT, BASE_CLASS, JUSTIFY_CONTENT, GUTTER_VALUES, CELL_NUMBERS, BREAKPOINTS } from './settings';
import { jsx as _jsx } from "react/jsx-runtime";

var transition = function transition(_ref) {
  var isGapless = _ref.isGapless,
      oldProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var gutter = oldProps.gutter || isGapless ? 0 : undefined;
  return _extends({
    gutter: gutter
  }, oldProps);
};

var getGutterClassNames = function getGutterClassNames(gutterConfig) {
  if (gutterConfig === void 0) {
    gutterConfig = {};
  }

  if (GUTTER_VALUES.includes(gutterConfig)) {
    return BASE_CLASS + "--gutter-" + BREAKPOINTS.XXS + "-" + gutterConfig;
  } else if (typeof gutterConfig === 'object') {
    return Object.entries(gutterConfig).map(function (_ref2) {
      var key = _ref2[0],
          value = _ref2[1];
      return Object.values(BREAKPOINTS).includes(key) ? BASE_CLASS + "--gutter-" + key + "-" + value : null;
    }).filter(function (value) {
      return value !== null;
    }).join(' ');
  }

  return null;
};

function LayoutGrid(_ref3) {
  var alignContent = _ref3.alignContent,
      alignItems = _ref3.alignItems,
      children = _ref3.children,
      justifyContent = _ref3.justifyContent,
      gutter = _ref3.gutter;
  var classNames = cx("" + BASE_CLASS, Object.values(ALIGN_CONTENT).includes(alignContent) && BASE_CLASS + "--ac-" + alignContent, Object.values(ALIGN_ITEMS).includes(alignItems) && BASE_CLASS + "--ai-" + alignItems, Object.values(JUSTIFY_CONTENT).includes(justifyContent) && BASE_CLASS + "--jc-" + justifyContent, getGutterClassNames(gutter));
  return /*#__PURE__*/_jsx("div", {
    className: classNames,
    children: children
  });
}

LayoutGrid.displayName = 'LayoutGrid';

var DeprecatedLayoutGrid = function DeprecatedLayoutGrid(props) {
  return /*#__PURE__*/_jsx(LayoutGrid, _extends({}, transition(props)));
};

export default LayoutGrid;
export { DeprecatedLayoutGrid, LayoutGridItem, ALIGN_CONTENT as LayoutGridAlignContent, ALIGN_ITEMS as LayoutGridAlignItems, JUSTIFY_CONTENT as LayoutGridJustifyContent, GUTTER_VALUES as LayoutGridGutterValues, CELL_NUMBERS as LayoutGridCellNumbers, BREAKPOINTS as LayoutGridBreakpoints };
